==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/corridor/dialogs_fr.lua <==

dialogId("ch-m-rozsvit0", "font_small", "Turn on the lights, NOW!")
dialogStr("Allume la lumière, MAINTENANT !")


dialogId("ch-m-rozsvit1", "font_small", "What do you think you are doing?")
dialogStr("Qu'essaies-tu de faire ?")


dialogId("ch-m-rozsvit2", "font_small", "Cut it out and turn on the lights.")
dialogStr("Arrête ça et allume la lumière.")


dialogId("ch-v-pockej0", "font_big", "Wait, I`ll try to find the switch.")
dialogStr("Attends, j'essaie de trouver l'interrupteur.")


dialogId("ch-v-pockej1", "font_big", "I can`t. The dang switch fell down.")
dialogStr("Je ne peux pas. l'interrupteur est tombé.")


dialogId("ch-v-pockej2", "font_big", "Turn on the lights yourself, if you`re so smart.")
dialogStr("Allume la lumière toi même, si tu es si pressée.")


dialogId("ch-v-halo0", "font_big", "Where are you?")
dialogStr("Où est-ce que tu es ?")


dialogId("ch-v-halo1", "font_big", "Hello-o-o.")
dialogStr("Hello-o-o.")


dialogId("ch-v-halo2", "font_big", "Say something.")
dialogStr("Dis quelque chose.")


dialogId("ch-m-tady0", "font_small", "Here.")
dialogStr("Ici.")


dialogId("ch-m-tady1", "font_small", "Here I am.")
dialogStr("Je suis là.")


dialogId("ch-m-tady2", "font_small", "I am right over here.")
dialogStr("Je suis là voyons.")


dialogId("ch-m-bojim0", "font_small", "Where are you, I am afraid.")
dialogStr("Où es-tu, j'ai peur.")


dialogId("ch-m-bojim1", "font_small", "I`m afraid of the dark.")
dialogStr("J'ai peur du noir.")


dialogId("ch-m-bojim2", "font_small", "Please don`t leave. It`s so dark in here.")
dialogStr("S'il te plaît ne pars pas. Il fait si noir ici.")


dialogId("ch-v-neboj0", "font_big", "Don`t be afraid. I`m here.")
dialogStr("N'aie pas peur. Je suis là.")


dialogId("ch-v-neboj1", "font_big", "Stop whining. We`ll manage.")
dialogStr("Arrête de geindre. Nous allons nous en sortir.")


dialogId("ch-v-neboj2", "font_big", "There`s nothing to be afraid of.")
dialogStr("Il n'y a pas de quoi avoir peur.")


dialogId("ch-m-doufam", "font_small", "I hope it doesn`t kick me...")
dialogStr("J'espère qu'il ne va pas me donner un coup de pied.")


dialogId("ch-m-blik0", "font_small", "This flickering light is beginning to make my eyes hurt.")
dialogStr("Cette lumière clignotante me blesse les yeux.")


dialogId("ch-m-blik1", "font_small", "I never thought I`d be so glad to see you again.")
dialogStr("Je n'imaginais pas être si contente de te revoir.")


dialogId("ch-m-blik2", "font_small", "Finally, the lights are back on...")
dialogStr("Finalement, la lumière est revenue.")


dialogId("ch-v-pozor", "font_big", "Be careful. It bites!")
dialogStr("Attention. Ca mords.")


dialogId("ch-v-robopes", "font_big", "Look! That must be... ROBODOG!")
dialogStr("Regarde ! Ce doit être... ROBOCHIEN !")


dialogId("ch-m-ten", "font_small", "What? THAT robodog?!?")
dialogStr("Pardon ? CA robochien ?!?")


dialogId("ch-v-zapada", "font_big", "Well now it all makes sense.")
dialogStr("Et bien, maintenant je comprends tout.")


dialogId("ch-m-odpoved0", "font_small", "Including the Cuban missile crisis and Nostradamus` prophecies.")
dialogStr("Tu inclus la crise des missiles de Cuba et les prophéties de Nostradamus.")


dialogId("ch-m-odpoved1", "font_small", "Including the murder of John Lennon and the Tunguzian meteor.")
dialogStr("Tu inclus le meurtre de John Lennon et la météorite de Tunguza.")


dialogId("ch-m-odpoved2", "font_small", "Including the Challenger explosion and the Battle of Bull Run.")
dialogStr("Tu inclus l'explosion de la navette Challenger et le mythe du King.")


dialogId("ch-m-odpoved3", "font_small", "Including the Chernobyl meltdown and the wreck of Noah`s Ark.")
dialogStr("Tu inclus la catastrophe de TChernobyl et l'épave de l'arche de Noé.")


dialogId("ch-v-smysl", "font_big", "Now I can see the rationale behind this game.")
dialogStr("Maintenant je peux voir le coté rationnel de ce jeu.")


dialogId("ch-m-vubec", "font_small", "And also the meaning of life, the universe and everything.")
dialogStr("Et aussi le sens de la vie, de l'univers et du reste.")


dialogId("ch-x-click1", "font_darkgrey", "CLICK")
dialogStr("CLICK")


dialogId("ch-x-click2", "font_lightgrey", "CLICK")
dialogStr("CLICK")


dialogId("ch-r-nevsimej0", "font_robodog", "Don`t listen to them, player. They are kidding you.")
dialogStr("Ne les écoute pas, joueur. Ils se moquent de toi.")


dialogId("ch-r-nevsimej1", "font_robodog", "Don`t listen to them, player. They are trying to be funny.")
dialogStr("Ne les écoute pas, joueur. Ils essaient d'être drôles.")


dialogId("ch-r-nevsimej2", "font_robodog", "Don`t listen to them, player. They are trying to fool you.")
dialogStr("Ne les écoute pas, joueur. Ils vont te rendre fou.")


dialogId("ch-r-hracka", "font_robodog", "I am but a humble cybernetic toy.")
dialogStr("Je ne suis qu'un simple jouet cybernétique.")


dialogId("ch-r-ikdyz0", "font_robodog", "Though originally I was to be a scooter.")
dialogStr("Même si au départ je devais être un scooter.")


dialogId("ch-r-ikdyz1", "font_robodog", "Though originally I was to be a lawn-mower.")
dialogStr("Même s'il était prévu que je sois une tondeuse à gazon.")


dialogId("ch-r-ikdyz2", "font_robodog", "Though originally I was to be a space orbital station.")
dialogStr("Même s'il était prévu que je sois une station orbitale.")


dialogId("ch-r-ikdyz3", "font_robodog", "Though orginally I was to be a piece of cake.")
dialogStr("Même si j'aurais dû être un morceau de gâteau.")


dialogId("ch-r-anavic0", "font_robodog", "And I visited Cuba only once.")
dialogStr("Et je n'ai visité Cuba qu'une seule fois.")


dialogId("ch-r-anavic1", "font_robodog", "And everybody knows somebody else murdered him, they can`t prove anything.")
dialogStr("Et tout le monde sait que quelqu'un d'autre l'a tué, ils ne peuvent pas tout prouver.")


dialogId("ch-r-anavic2", "font_robodog", "And who cares about a few soldiers.")
dialogStr("Et qui se soucie de quelques soldats.")


dialogId("ch-r-anavic3", "font_robodog", "And they told me that the regulatory rod wasn`t important.")
dialogStr("Et ils m'ont dit que ce bouton de régulation n'était pas important.")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/corridor/dialogs_fr.lua <==

dialogId("ch-m-rozsvit0", "font_small", "Turn on the lights, NOW!")
dialogStr("Allume la lumière, MAINTENANT !")


dialogId("ch-m-rozsvit1", "font_small", "What do you think you are doing?")
dialogStr("Qu'essaies-tu de faire ?")


dialogId("ch-m-rozsvit2", "font_small", "Cut it out and turn on the lights.")
dialogStr("Arrête ça et allume la lumière.")


dialogId("ch-v-pockej0", "font_big", "Wait, I’ll try to find the switch.")
dialogStr("Attends, j'essaie de trouver l'interrupteur.")


dialogId("ch-v-pockej1", "font_big", "I can’t. The dang switch fell down.")
dialogStr("Je ne peux pas. l'interrupteur est tombé.")


dialogId("ch-v-pockej2", "font_big", "Turn on the lights yourself, if you’re so smart.")
dialogStr("Allume la lumière toi même, si tu es si maligne.")


dialogId("ch-v-halo0", "font_big", "Where are you?")
dialogStr("Où est-ce que tu es ?")


dialogId("ch-v-halo1", "font_big", "Hello-o-o.")
dialogStr("Hello-o-o.")


dialogId("ch-v-halo2", "font_big", "Say something.")
dialogStr("Dis quelque chose.")


dialogId("ch-m-tady0", "font_small", "Here.")
dialogStr("Ici.")


dialogId("ch-m-tady1", "font_small", "Here I am.")
dialogStr("Je suis là.")


dialogId("ch-m-tady2", "font_small", "I am right over here.")
dialogStr("Je suis juste là.")


dialogId("ch-m-bojim0", "font_small", "Where are you, I am afraid.")
dialogStr("Où es-tu, j'ai peur.")


dialogId("ch-m-bojim1", "font_small", "I’m afraid of the dark.")
dialogStr("J'ai peur du noir.")


dialogId("ch-m-bojim2", "font_small", "Please don’t leave. It’s so dark in here.")
dialogStr("S'il te plaît ne pars pas. Il fait si noir ici.")


dialogId("ch-v-neboj0", "font_big", "Don’t be afraid. I’m here.")
dialogStr("N'aie pas peur. Je suis là.")


dialogId("ch-v-neboj1", "font_big", "Stop whining. We’ll manage.")
dialogStr("Arrête de geindre. Nous allons nous en sortir.")


dialogId("ch-v-neboj2", "font_big", "There’s nothing to be afraid of.")
dialogStr("Il n'y a pas de quoi avoir peur.")


dialogId("ch-m-doufam", "font_small", "I hope it doesn’t kick me...")
dialogStr("J'espère qu'il ne va pas me donner un coup de pied.")


dialogId("ch-m-blik0", "font_small", "This flickering light is beginning to make my eyes hurt.")
dialogStr("Cette lumière clignotante me blesse les yeux.")


dialogId("ch-m-blik1", "font_small", "I never thought I’d be so glad to see you again.")
dialogStr("Je n'imaginais pas être si contente de te revoir.")


dialogId("ch-m-blik2", "font_small", "Finally, the lights are back on...")
dialogStr("Finalement, la lumière est revenue.")


dialogId("ch-v-pozor", "font_big", "Be careful. It bites!")
dialogStr("Attention. Ça mord.")


dialogId("ch-v-robopes", "font_big", "Look! That must be... ROBODOG!")
dialogStr("Regarde ! Ce doit être... ROBOCHIEN !")


dialogId("ch-m-ten", "font_small", "What? THAT robodog?!?")
dialogStr("Pardon ? ÇA robochien ?!?")


dialogId("ch-v-zapada", "font_big", "Well now it all makes sense.")
dialogStr("Et bien, maintenant je comprends tout.")


dialogId("ch-m-odpoved0", "font_small", "Including the Cuban missile crisis and Nostradamus’ prophecies.")
dialogStr("Y compris la crise des missiles de Cuba et les prophéties de Nostradamus.")


dialogId("ch-m-odpoved1", "font_small", "Including the murder of John Lennon and the Tunguzian meteor.")
dialogStr("Y compris le meurtre de John Lennon et la météorite de Tunguza.")


dialogId("ch-m-odpoved2", "font_small", "Including the Challenger explosion and the Battle of Bull Run.")
dialogStr("Y compris l'explosion de la navette Challenger et le mythe du King.")


dialogId("ch-m-odpoved3", "font_small", "Including the Chernobyl meltdown and the wreck of Noah’s Ark.")
dialogStr("Y compris la catastrophe de TChernobyl et l'épave de l'arche de Noé.")


dialogId("ch-v-smysl", "font_big", "Now I can see the rationale behind this game.")
dialogStr("Maintenant je peux voir le côté rationnel de ce jeu.")


dialogId("ch-m-vubec", "font_small", "And also the meaning of life, the universe and everything.")
dialogStr("Et aussi le sens de la vie, de l'univers et du reste.")


dialogId("ch-x-click1", "font_darkgrey", "CLICK")
dialogStr("CLIC")


dialogId("ch-x-click2", "font_lightgrey", "CLICK")
dialogStr("CLIC")


dialogId("ch-r-nevsimej0", "font_robodog", "Don’t listen to them, player. They are kidding you.")
dialogStr("Ne les écoute pas, joueur. Ils se moquent de toi.")


dialogId("ch-r-nevsimej1", "font_robodog", "Don’t listen to them, player. They are trying to be funny.")
dialogStr("Ne les écoute pas, joueur. Ils essaient d'être drôles.")


dialogId("ch-r-nevsimej2", "font_robodog", "Don’t listen to them, player. They are trying to fool you.")
dialogStr("Ne les écoute pas, joueur. Ils essaient de t'embobiner.")


dialogId("ch-r-hracka", "font_robodog", "I am but a humble cybernetic toy.")
dialogStr("Je ne suis qu'un simple jouet cybernétique.")


dialogId("ch-r-ikdyz0", "font_robodog", "Though originally I was to be a scooter.")
dialogStr("Même si au départ je devais être un scooter.")


dialogId("ch-r-ikdyz1", "font_robodog", "Though originally I was to be a lawn-mower.")
dialogStr("Même s'il était prévu que je sois une tondeuse à gazon.")


dialogId("ch-r-ikdyz2", "font_robodog", "Though originally I was to be a space orbital station.")
dialogStr("Même s'il était prévu que je sois une station orbitale.")


dialogId("ch-r-ikdyz3", "font_robodog", "Though orginally I was to be a piece of cake.")
dialogStr("Même si j'aurais dû être du gâteau.")


dialogId("ch-r-anavic0", "font_robodog", "And I visited Cuba only once.")
dialogStr("Et je n'ai visité Cuba qu'une seule fois.")


dialogId("ch-r-anavic1", "font_robodog", "And everybody knows somebody else murdered him, they can’t prove anything.")
dialogStr("Et tout le monde sait que quelqu'un d'autre l'a tué, ils ne peuvent pas tout prouver.")


dialogId("ch-r-anavic2", "font_robodog", "And who cares about a few soldiers.")
dialogStr("Et qui se soucie de quelques soldats.")


dialogId("ch-r-anavic3", "font_robodog", "And they told me that the regulatory rod wasn’t important.")
dialogStr("Et ils m'ont dit que ce levier de réglage n'était pas important.")
